/***************************************************************************
**
**  This file is part of QGpGuiWave.
**
**  QGpGuiWave is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  QGpGuiWave is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2019-02-18
**  Copyright: 2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef DISPERSIONPLOTPROXY_H
#define DISPERSIONPLOTPROXY_H

#include "ModalPlotProxy.h"
#include "QGpGuiWaveDLLExport.h"

namespace QGpGuiWave {

  class QGPGUIWAVE_EXPORT DispersionPlotProxy : public ModalPlotProxy
  {
  public:
    void setYAxisProperties(Axis * a);
  };

} // namespace QGpGuiWave

#endif // DISPERSIONPLOTPROXY_H

